%%%  Calculate n2 serving the FEA model

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Objectif function

function n2 = calcul_n2(input)

global input0 inputmax inputmin
global c b kr rhocuivre alphacuivre l2spire muo a d n1 V2 V1 fp2 I2 
global Text Rcuivreair Rferair Rfercuivre l1spire Pfer f S1fil S2fil

a=input(1);
b=input(2);
c=input(3);
d=input(4);
n1=input(5);
S1fil=input(6);
S2fil=input(7);

% Constant spcifications 

V2 = 24; % (V) secondary tension
V1 = 230; % (V) primairy tension
f = 50; % (Hz) frequence
fp2 = 0.8; % power factor
I2 = 8; % (A) secondary current
Text = 40; % (C) ambiante temperature
q = 1; % (W/kg) quality of sheet
kr = 0.5; % filling coefficient
h = 10; % (W/m2/K) 	coefficient of convection of the air 
lambda = 0.15; % (W/m/K) coefficient of conduction of the insulator
e_isol = 1E-3; % (m) thickness of insulator
mvfer = 7800; % (kg/m3) density of iron
mvcuivre = 8800; % (kg/m3) density of copper
muo = 4*pi*1E-7; % permability 
rhocuivre = 1.72E-8; % resistivity of copper
alphacuivre = 3.8E-3; % variation of the resistivity of copper

% Solve 12 equations sequentially

Bm = 1/4*V1*sqrt(2)/(n1*a*d*pi*f);
l1spire = 2*(d+2*a)+pi*c/2; 
Mfer = 4*a*d*(2*a+b+c)*mvfer;
Pfer = q*Mfer*f/50*(Bm/1)^2;
Rfercuivre = e_isol/(lambda*b*(4*a+2*d));
Sferair = 4*a*(4*a+b+2*c)+2*d*(6*a+b+2*c);
Rferair = 1/(h*Sferair);
Scuivreair = b*(4*a+2*pi*c);
Rcuivreair = 1/(h*Scuivreair);
l2spire = 2*(d+2*a)+pi*3*c/2;
l1 = 1/24*muo*n1^2*c*(16*a+8*d+3*pi*c)/b;

% Solve of implicit system of 8 equations by Dogleg algorithm

% r2 = rhocuivre*(1+alphacuivre*Tcuivre)*n2*l2spire/S2fil;
% X2 = 1/3*muo*n2^2*c*(4*a+2*d+pi*c)/b;
% n2 = n1*(V2+DV2)/V1;
% DV2 = (R2*fp2+X2*sin(acos(fp2)))*I2;
% Pj = R2*I2^2;
% Tcuivre = Text+Rcuivreair*(Rferair*Pfer+(Rferair+Rfercuivre)*Pj)/(Rcuivreair+Rferair+Rfercuivre);
% r1 = rhocuivre*(1+alphacuivre*Tcuivre)*n1*l1spire/S1fil;
% R2 = r2+(n2/n1)^2*r1;


% Give initial values

Tcuivre=1;
DV2=1;
n2 = n1*(V2+DV2)/V1;
r2 = rhocuivre*(1+alphacuivre*Tcuivre)*n2*l2spire/S2fil;
r1 = rhocuivre*(1+alphacuivre*Tcuivre)*n1*l1spire/S1fil;
R2 = r2+(n2/n1)^2*r1;
Pj = R2*I2^2;
X2 = 1/3*muo*n2^2*c*(4*a+2*d+pi*c)/b*2*pi*f;


x0=[r2 X2 n2 DV2 Pj Tcuivre r1 R2];

options=optimset('TolX',1e-6,'Display','off','LargeScale','off','Jacobian','on',...
    'NonlEqnAlgorithm','dogleg','MaxFunEvals',1000);
x=fsolve(@sys_equa_silmu,x0,options);

r2=x(1);
X2=x(2);
n2=x(3);
DV2=x(4);
Pj=x(5);
Tcuivre=x(6);
r1=x(7);
R2=x(8);
